As btrfs_parse_device_options() now doesn't only parse the -o device mount
option but -o auth_key as well, it makes sense to rename it back to
btrfs_parse_early_options().

This reverts commit fa59f27c8c35bbe00af8eff23de446a7f4b048b0.

Signed-off-by: Johannes Thumshirn <[email protected]>
---
 fs/btrfs/super.c | 11 ++++++-----
 1 file changed, 6 insertions(+), 5 deletions(-)

diff --git a/fs/btrfs/super.c b/fs/btrfs/super.c
index 313ef7fc2bdf..3708264a7335 100644
--- a/fs/btrfs/super.c
+++ b/fs/btrfs/super.c
@@ -470,8 +470,9 @@ int btrfs_parse_options(struct btrfs_fs_info *info, char 
*options,
                case Opt_subvolrootid:
                case Opt_device:
                        /*
                         * These are parsed by btrfs_parse_subvol_options or
                         * btrfs_parse_device_options and can be ignored here.
                         */
                        break;
                case Opt_nodatasum:
@@ -893,7 +894,7 @@ int btrfs_parse_options(struct btrfs_fs_info *info, char 
*options,
  * All other options will be parsed on much later in the mount process and
  * only when we need to allocate a new super block.
  */
-static int btrfs_parse_device_options(struct btrfs_fs_info *info,
+static int btrfs_parse_early_options(struct btrfs_fs_info *info,
                                      const char *options, fmode_t flags,
                                      void *holder)
 {
@@ -975,7 +976,7 @@ static int btrfs_parse_subvol_options(const char *options, 
char **subvol_name,
 
        /*
         * strsep changes the string, duplicate it because
         * btrfs_parse_device_options gets called later
         */
        opts = kstrdup(options, GFP_KERNEL);
        if (!opts)
@@ -1532,7 +1533,7 @@ static struct dentry *btrfs_mount_root(struct 
file_system_type *fs_type,
        }
 
        mutex_lock(&uuid_mutex);
-       error = btrfs_parse_device_options(fs_info, data, mode, fs_type);
+       error = btrfs_parse_early_options(fs_info, data, mode, fs_type);
        if (error) {
                mutex_unlock(&uuid_mutex);
                goto error_fs_info;
@@ -470,8 +470,9 @@ int btrfs_parse_options(struct btrfs_fs_info *info, char 
                case Opt_device:
                        /*
-                        * These are parsed by btrfs_parse_subvol_options or
-                        * btrfs_parse_device_options and can be ignored here.
+                        * These are parsed by btrfs_parse_subvol_options
+                        * and btrfs_parse_early_options
+                        * and can be happily ignored here.
                         */
                        break;
@@ -975,7 +976,7 @@ static int btrfs_parse_subvol_options(const char *options, 
        /*
         * strsep changes the string, duplicate it because
-        * btrfs_parse_device_options gets called later
+        * btrfs_parse_early_options gets called later
         */
        opts = kstrdup(options, GFP_KERNEL);
-- 
2.16.4

Reply via email to